McpNotification class

MCP Notification (request without ID)

Represents a JSON-RPC notification - a request that doesn't expect a response.

Constructors

McpNotification({required String method, Map<String, dynamic>? params})
McpNotification.fromJson(Map<String, dynamic> json)
Create notification from JSON map
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
method String
Method name
final
params Map<String, dynamic>?
Optional parameters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited