McpProtocol class

JSON-RPC 2.0 protocol constants

Constructors

McpProtocol()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

contentType → const String
errorInternalError → const int
errorInvalidParams → const int
errorInvalidRequest → const int
errorMethodNotFound → const int
errorParseError → const int
jsonRpcVersion → const String
serverErrorEnd → const int
serverErrorStart → const int