description property
String
get
description
Tool description for AI agents
Should clearly explain what the tool does and when to use it.
Implementation
String get description;
Tool description for AI agents
Should clearly explain what the tool does and when to use it.
String get description;