SkillAddCommand class
Command to add a skill from a GitHub repository
Constructors
- SkillAddCommand({String skillsPath = '.ai/skills', String? repo, String? skillName, bool force = false})
- Create a new skill add command
Properties
- description → String
-
Command description
no setteroverride
- force → bool
-
Force flag (skip confirmations)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name (e.g., 'skill:list')
no setteroverride
- repo → String?
-
Repository to fetch from (format: owner/repo)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skillName → String?
-
Skill name to fetch (optional, lists all if null)
final
- skillsPath → String
-
Path to skills directory
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< void> -
Run the command
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited