SkillRemoveCommand class

Command to remove a skill

Inheritance

Constructors

SkillRemoveCommand({String skillsPath = '.ai/skills', String? skillName, bool force = false})
Create a new skill remove command

Properties

description String
Command description
no setteroverride
force bool
Force flag (skip confirmations)
final
hashCode int
The hash code for this object.
no setterinherited
name String
Command name (e.g., 'skill:list')
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillName String?
Name of the skill to remove
final
skillsPath String
Path to skills directory
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
Run the command
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited