SkillRenderCommand class

Command to render a skill template

Inheritance

Constructors

SkillRenderCommand({String skillsPath = '.ai/skills', String? skillName, String? outputPath})
Create a new skill render command

Properties

description String
Command description
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
Command name (e.g., 'skill:list')
no setteroverride
outputPath String?
Output file path (optional)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillName String?
Name of the skill to render
final
skillsPath String
Path to skills directory
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
Run the command
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited