AgentType enum

Supported AI agent types

Inheritance
Available extensions

Values

claudeCode → const AgentType

Claude Code (Anthropic's CLI tool)

openCode → const AgentType

OpenCode AI assistant

cursor → const AgentType

Cursor AI editor

copilot → const AgentType

GitHub Copilot

Properties

displayName String

Available on AgentType, provided by the AgentTypeExtension extension

Get the display name for the agent type
no setter
hasFileSystemAccess bool

Available on AgentType, provided by the AgentTypeExtension extension

Check if this agent has file system access
no setter
hashCode int
The hash code for this object.
no setterinherited
identifier String

Available on AgentType, provided by the AgentTypeExtension extension

Get the agent identifier
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsStreaming bool

Available on AgentType, provided by the AgentTypeExtension extension

Check if this agent supports streaming responses
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AgentType>
A constant List of the values in this enum, in order of their declaration.