AgentTypeExtension extension
Extension to get display names and properties for AgentType
- on
Properties
- displayName → String
-
Available on AgentType, provided by the AgentTypeExtension extension
Get the display name for the agent typeno setter - hasFileSystemAccess → bool
-
Available on AgentType, provided by the AgentTypeExtension extension
Check if this agent has file system accessno setter - identifier → String
-
Available on AgentType, provided by the AgentTypeExtension extension
Get the agent identifierno setter - supportsStreaming → bool
-
Available on AgentType, provided by the AgentTypeExtension extension
Check if this agent supports streaming responsesno setter