GuidelineComposer class

Composes guidelines for AI agents working with ServerPod

The GuidelineComposer combines base agent guidelines with composed skills and project context to create comprehensive instructions for AI agents.

Constructors

GuidelineComposer({required SkillComposer skillComposer})
Create a new guideline composer
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillComposer SkillComposer
Skill composer for composing skill sections
final

Methods

composeForAgent(AgentType agent, List<String> skillNames, ProjectContext context) Future<String>
Compose guidelines for an AI agent
composeWithMetadata(AgentType agent, List<String> skillNames, ProjectContext context, {Map<String, dynamic>? metadata}) Future<String>
Compose guidelines with additional metadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getSupportedAgentTypes() List<AgentType>
Get all supported agent types
isAgentTypeSupported(AgentType agentType) bool
Check if an agent type is supported
parseAgentType(String agentTypeString) AgentType
Parse agent type from string