GuidelineWriteException class

Exception thrown when guideline writing fails

Implemented types

Constructors

GuidelineWriteException(String message, [String? filePath])
Create exception
const

Properties

filePath String?
Optional file path
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited