InstallConfig class

Installation configuration

Constructors

InstallConfig({List<String> features = const ['guidelines', 'skills', 'mcp'], List<String> skills = const [], List<String> agents = const [], bool overwrite = false, String skillsPath = '.ai/skills'})
const

Properties

agents List<String>
Selected AI editors to configure
final
features List<String>
Selected features to install
final
hashCode int
The hash code for this object.
no setterinherited
installGuidelines bool
Check if guidelines should be installed
no setter
installMcp bool
Check if MCP should be installed
no setter
installSkills bool
Check if skills should be installed
no setter
overwrite bool
Whether to overwrite existing files
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skills List<String>
Selected skills to include
final
skillsPath String
Path to skills directory
final

Methods

copyWith({List<String>? features, List<String>? skills, List<String>? agents, bool? overwrite, String? skillsPath}) InstallConfig
Create a copy with modified fields
hasFeature(String featureId) bool
Check if a feature is selected
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited