InstallFeature class

Feature that can be installed

Constructors

InstallFeature({required String id, required String displayName, required String description, bool isDefault = true})
const

Properties

description String
Description
final
displayName String
Display name
final
hashCode int
The hash code for this object.
no setterinherited
id String
Feature identifier
final
isDefault bool
Whether this feature is selected by default
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findById(String id) InstallFeature?
Find feature by ID

Constants

all → const List<InstallFeature>
All available install features