McpPrompt class abstract
Base interface for all MCP prompts
Constructors
Properties
-
argumentsSchema
→ Map<
String, dynamic> -
Input arguments schema
no setter
- description → String
-
Prompt description
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Get prompt metadata
no setter
- name → String
-
Prompt name (must be unique)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
Map< String, dynamic> arguments) → Future<String> - Generate the prompt
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited