McpPromptRegistry class

Prompt registry

Constructors

McpPromptRegistry()

Properties

count int
Get prompt count
no setter
hashCode int
The hash code for this object.
no setterinherited
promptMetadata List<Map<String, dynamic>>
List all prompt metadata
no setter
promptNames List<String>
List all prompt names
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all prompts
generate(String name, Map<String, dynamic> arguments) Future<String>
Generate a prompt by name
getPrompt(String name) McpPrompt?
Get a prompt by name
hasPrompt(String name) bool
Check if a prompt exists
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(McpPrompt prompt) → void
Register a prompt
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited