InitializeResult class

Result of parsing an initialize request

Constructors

InitializeResult({required String protocolVersion, required Map<String, dynamic> capabilities, Map<String, dynamic>? clientInfo})

Properties

capabilities Map<String, dynamic>
final
clientInfo Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
protocolVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited