InitializeResponse class

Initialize response

Represents the response to an initialize request

Constructors

InitializeResponse({required String protocolVersion, required Map<String, dynamic> capabilities, Map<String, dynamic>? serverInfo})
InitializeResponse.standard({Map<String, dynamic>? additionalCapabilities, Map<String, dynamic>? serverInfo})
Create a standard initialize response
factory

Properties

capabilities Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
protocolVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverInfo Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON map for MCP response
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited