ToolResultResponse class

Tool result response

Represents the result of a tool execution

Constructors

ToolResultResponse({required String content, bool isError = false})
ToolResultResponse.error(String message)
Create an error tool result
factory
ToolResultResponse.success(String content)
Create a successful tool result
factory

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON map for MCP response
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited