MCPServerConfig class
Server configuration for MCP
Constructors
- MCPServerConfig({required String name, required String version, String protocolVersion = '2024-11-05'})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Server name
final
- protocolVersion → String
-
Server protocol version
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Server version
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited