EndpointInfo class
Information about an endpoint
Constructors
-
EndpointInfo({required String name, required String file, int methodCount = 0, List<
MethodInfo> methods = const []}) -
const
Properties
- file → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodCount → int
-
final
-
methods
→ List<
MethodInfo> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited