MethodInfo class

Information about a method in an endpoint

Constructors

MethodInfo({required String name, required String returnType, required String signature, required int lineNumber})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lineNumber int
final
name String
final
returnType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited