ModelInfo class

Information about a model

Constructors

ModelInfo({required String name, required String file, String? namespace, List<FieldInfo> fields = const []})
const

Properties

fields List<FieldInfo>
final
file String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
namespace String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited