ProjectContext class

Project context information

Constructors

ProjectContext({required String projectName, required String serverpodVersion, required String rootPath, DatabaseType databaseType = DatabaseType.unknown, bool hasEndpoints = false, bool hasModels = false, bool hasMigrations = false, bool usesRedis = false, List<EndpointInfo> endpoints = const [], List<ModelInfo> models = const [], List<MigrationInfo> migrations = const []})
const
ProjectContext.fromProject(ServerPodProject project)
Create project context from a ServerPod project
factory

Properties

databaseType DatabaseType
Database type
final
endpointCount int
Get endpoint count
no setter
endpoints List<EndpointInfo>
List of endpoint information
final
hasEndpoints bool
Whether the project has endpoints
final
hashCode int
The hash code for this object.
no setterinherited
hasMigrations bool
Whether the project has migrations
final
hasModels bool
Whether the project has models
final
migrationCount int
Get migration count
no setter
migrations List<MigrationInfo>
List of migration information
final
modelCount int
Get model count
no setter
models List<ModelInfo>
List of model information
final
projectName String
Project name
final
rootPath String
Project root path
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverpodVersion String
ServerPod version
final
usesRedis bool
Whether the project uses Redis
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toTemplateVars() Map<String, dynamic>
Convert to template variables map

Operators

operator ==(Object other) bool
The equality operator.
inherited