MethodParameter class

Method parameter definition

Constructors

MethodParameter({required String type, required String name, bool isSession = false})

Properties

hashCode int
The hash code for this object.
no setteroverride
isSession bool
Whether this is the Session session parameter
final
name String
Parameter name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Parameter type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override