MethodParser class
Parser for endpoint method signatures
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
findEndpointFiles(
String serverPackagePath) → List< String> - Find all endpoint files in the server package
-
parseFile(
String filePath) → List< EndpointMethod> - Parse all methods from an endpoint file