ServerPodLocator class
ServerPod service locator
Use this class to access ServerPod project information.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getProject(
{String? currentPath, bool forceReload = false}) → ServerPodProject? - Get the current ServerPod project
-
isInServerPodProject(
{String? currentPath}) → bool - Check if we're in a valid ServerPod project
-
resetCache(
) → void - Reset cached project (useful for testing)