ServerPodProject class

ServerPod project information

Constructors

ServerPodProject({required String rootPath, String? serverPath, String? clientPath, String? flutterPath})

Properties

clientPath String?
Client package path
final
configPath String?
Config directory path
no setter
endpointFiles List<String>
Get all endpoint files
no setter
flutterPath String?
Flutter package path
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Check if project is valid
no setter
migrationFiles List<File>
List all migration files
no setter
migrationsPath String?
Migrations directory path
no setter
modelFiles List<String>
Get all model file paths
no setter
models List<SpyYamlModel>
Get all .spy.yaml model definitions
no setter
rootPath String
Project root (monorepo root)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverPath String?
Server package path
final

Methods

getConfigFile(String environment) File?
Get config file path for environment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detect([String? currentPath]) ServerPodProject?
Create from detected project root