SpyYamlField class

Field definition from .spy.yaml

Constructors

SpyYamlField({required String name, required String type, bool isOptional = false})

Properties

dartType String
Get the Dart type with nullable suffix
no setter
hashCode int
The hash code for this object.
no setteroverride
isOptional bool
Whether field is optional (has ? suffix in type)
final
name String
Field name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Field type (String, int, DateTime, UserModel, etc.)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override