SpyYamlModel class
Protocol model definition parsed from .spy.yaml
Constructors
-
SpyYamlModel({required String className, required List<
SpyYamlField> fields, required String filePath})
Properties
- className → String
-
Model class name
final
-
fields
→ List<
SpyYamlField> -
Field definitions
final
- filePath → String
-
Original file path
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- namespace → String
-
Model namespace (derived from directory structure)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override