SpyYamlParser class

Parser for .spy.yaml files

Constructors

SpyYamlParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fieldPattern RegExp
Get field pattern for parsing (utility)
no setter

Static Methods

findSpyYamlFiles(String serverPackagePath) List<String>
Find all .spy.yaml files in the server package
parseAll(String serverPackagePath) List<SpyYamlModel>
Parse all .spy.yaml models in the server package
parseFile(String filePath) SpyYamlModel?
Parse a single .spy.yaml file