Skill class

A ServerPod Boost skill

Constructors

Skill({required String name, String description = '', required String template, SkillMetadata? metadata})
const
Skill.fromFile(String name, String template, {SkillMetadata? metadata})
Create a skill from a template file
factory

Properties

description String
Human-readable description
final
hasDependencies bool
Check if this skill has any dependencies
no setter
hashCode int
The hash code for this object.
no setteroverride
hasVersionRequirement bool
Check if this skill has a minimum ServerPod version requirement
no setter
metadata SkillMetadata
Skill metadata
final
name String
Unique name of the skill
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String
Mustache template content
final

Methods

dependsOn(String skillName) bool
Check if this skill depends on another skill
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override