SkillNotFoundException class
Exception thrown when a required skill is missing
- Implemented types
Constructors
-
SkillNotFoundException(String skillName, [List<
String> searchedPaths = const []]) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchedPaths
→ List<
String> -
final
- skillName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited