TemplateRenderer class

Template renderer for skill templates

Constructors

TemplateRenderer({required ProjectContext context, Map<String, dynamic> customVars = const {}})
const

Properties

context ProjectContext
Project context for rendering
final
customVars Map<String, dynamic>
Additional custom variables
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templateVars Map<String, dynamic>
Get template variables as a map
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(String template, [Map<String, dynamic>? extraVars]) String
Render a template with context
toString() String
A string representation of this object.
inherited
withVars(Map<String, dynamic> vars) TemplateRenderer
Create a new renderer with additional custom variables

Operators

operator ==(Object other) bool
The equality operator.
inherited