LogEntry class

Log entry parsed from ServerPod log file

Constructors

LogEntry({required String timestamp, required String level, required String message, required String raw})

Properties

hashCode int
The hash code for this object.
no setterinherited
level String
Log level (INFO, WARNING, ERROR, etc.)
final
message String
Full log message (may contain newlines)
final
raw String
Raw entry text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
Timestamp from log entry
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited