FileTreeNode class

File tree node

Constructors

FileTreeNode({required String name, required String path, required bool isDirectory, int? size, List<FileTreeNode>? children})

Properties

children List<FileTreeNode>
Children (for directories)
final
hashCode int
The hash code for this object.
no setterinherited
isDirectory bool
Whether this is a directory
final
name String
Node name (file or directory name)
final
path String
Full path
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
File size (bytes) - null for directories
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON-serializable map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited