TinkerExecutionResult class

Result from isolate execution

Constructors

TinkerExecutionResult({required dynamic result, required String output, String? error, required int executionTime, required int memoryUsed})
const

Properties

error String?
final
executionTime int
final
hashCode int
The hash code for this object.
no setterinherited
memoryUsed int
final
output String
final
result → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited