TinkerSecurityConfig class

Security configuration for TinkerTool

Constructors

TinkerSecurityConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isEnabled() bool
Check if tinker is enabled via environment variable
validateCode(String code) String?
Validate code doesn't contain blocked imports
validateTimeout(int? timeout) String?
Validate timeout parameter

Constants

blockedImports → const List<String>
Blocked imports that could be dangerous
defaultTimeoutSeconds → const int
Default timeout in seconds
enabledEnvVar → const String
Environment variable to enable tinker
maxMemoryBytes → const int
Maximum memory usage in bytes (512MB)
maxTimeoutSeconds → const int
Maximum timeout in seconds