SkillConflictResolver class

Resolves naming conflicts between skills

This utility class helps resolve naming conflicts when multiple skills have the same name. It provides methods to detect conflicts and resolve them by either selecting the first occurrence (in simple cases) or requiring user intervention in advanced scenarios.

Constructors

SkillConflictResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(List<Skill> skills) Future<List<Skill>>
Resolve naming conflicts between skills
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getConflicts(List<Skill> skills) List<String>
Get list of conflicting names from a list of skills
hasConflicts(List<Skill> skills) bool
Check for conflicts in a list of skills