BoostMcpServer class
Boost MCP Server - wrapper around package:mcp_server
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> - Start the server
-
stop(
) → Future< void> - Stop the server
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{String? projectPath, bool verbose = false}) → Future< BoostMcpServer> - Create and configure the server