McpToolRegistry class
Tool registry for managing multiple tools
Constructors
Properties
- count → int
-
Get number of registered tools
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toolMetadata
→ List<
Map< String, dynamic> > -
List all tool metadata
no setter
-
toolNames
→ List<
String> -
List all registered tool names
no setter
Methods
-
clear(
) → void - Clear all registered tools
-
execute(
String name, McpRequest request) → Future< McpResponse> - Execute a tool by name
-
getTool(
String name) → McpTool? - Get a tool by name
-
hasTool(
String name) → bool - Check if a tool exists
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
McpTool tool) → void - Register a tool
-
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String name) → void - Unregister a tool by name
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited