AgentDetector class

Agent detector for finding installed AI editors

Constructors

AgentDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

supportedAgentDisplayNames List<String>
List all supported agent display names
no setter
supportedAgentNames List<String>
List all supported agent names
no setter

Static Methods

detect() Future<List<Agent>>
Detect all installed agents on the system
detectAll({required String basePath}) Future<List<Agent>>
Detect all agents (both system and project)
detectInProject(String basePath) Future<List<Agent>>
Detect all agents used in the current project
getAgent(String agentName) Agent?
Get agent by name
isAgentInProject(String agentName, String basePath) Future<bool>
Check if specific agent is used in project
isAgentInstalled(String agentName) Future<bool>
Detect specific agent by name