Command class abstract
Abstract base class for CLI commands
Constructors
- Command()
Properties
- description → String
-
Command description
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name (e.g., 'skill:list')
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< void> - Run the command
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited