InstallCommand class
Command to install ServerPod Boost features
Constructors
Properties
- description → String
-
Command description
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name (e.g., 'skill:list')
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< void> -
Run the command
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited