GuidelineWriter class
Writer for AI guideline files (AGENTS.md, CLAUDE.md)
Provides smart merge functionality to preserve user customizations when updating guideline files.
Constructors
- GuidelineWriter({required GuidelineComposer composer})
-
Create a new guideline writer
const
Properties
- composer → GuidelineComposer
-
Guideline composer for generating content
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
backupExisting(
String projectPath, String fileName) → Future< String?> - Backup existing guideline file
-
fileExists(
String projectPath, String fileName) → Future< bool> - Check if a guideline file exists
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readExisting(
String projectPath, String fileName) → Future< String?> - Read existing guideline file content
-
toString(
) → String -
A string representation of this object.
inherited
-
writeAgentsMd(
String projectPath, List< String> skillNames, {AgentType agent = AgentType.claudeCode, required ProjectContext context}) → Future<GuidelineWriteStatus> - Write AGENTS.md file with smart merge
-
writeClaudeMd(
String projectPath, List< String> skillNames, {AgentType agent = AgentType.claudeCode, required ProjectContext context}) → Future<GuidelineWriteStatus> - Write CLAUDE.md file with smart merge
-
writeDirectly(
String filePath, String content) → Future< void> - Write guidelines to a specific file path
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited