InstallResult class
Installation result
Constructors
-
InstallResult({bool success = true, List<
String> successes = const [], Map<String, String> failures = const {}, List<String> messages = const []}) -
const
-
InstallResult.failure(Map<
String, String> failures) -
Create a failed result
factory
-
InstallResult.success([List<
String> successes = const []]) -
Create a successful result
factory
Properties
-
failures
→ Map<
String, String> -
List of failed installations with errors
final
- hasFailures → bool
-
Check if there are any failures
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
String> -
Installation messages
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether installation was successful
final
-
successes
→ List<
String> -
List of successful installations
final
- total → int
-
Get total count of installations
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited