InitializeRequest class
Initialize request
Represents the initialize method call from the MCP protocol
- Inheritance
-
- Object
- MCPRequest<
InitializeResult> - InitializeRequest
Constructors
- InitializeRequest(McpRequest rawRequest)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawRequest → McpRequest
-
The raw MCP request
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
) → InitializeResult -
Parse the request parameters into the typed result
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
Validate the request parameters
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited