MCPRequest<T> class
abstract
Base class for typed MCP requests
- Implementers
Constructors
- MCPRequest(McpRequest rawRequest)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawRequest → McpRequest
-
The raw MCP request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
) → T - Parse the request parameters into the typed result
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validate the request parameters
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited