McpResource class abstract
Base interface for all MCP resources
- Implementers
Constructors
Properties
- description → String
-
Resource description
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Get resource metadata as a map (for resource listing)
no setter
- mimeType → String
-
Resource MIME type
no setter
- name → String
-
Resource name
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
Resource URI (must be unique)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Future< String> - Read the resource content
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited