McpResourceBase class abstract
Base class for resources
- Implemented types
Constructors
Properties
- description → String
-
Resource description
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Get resource metadata as a map (for resource listing)
no setterinherited
- mimeType → String
-
Resource MIME type
no setterinherited
- name → String
-
Resource name
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
Resource URI (must be unique)
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Future< String> -
Read the resource content
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited