McpResourceRegistry class
Resource registry for managing multiple resources
Constructors
Properties
- count → int
-
Get resource count
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceMetadata
→ List<
Map< String, dynamic> > -
List all resource metadata
no setter
-
resourceUris
→ List<
String> -
List all resource URIs
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clear all resources
-
getResource(
String uri) → McpResource? - Get a resource by URI
-
hasResource(
String uri) → bool - Check if a resource exists
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String uri) → Future< String> - Read a resource by URI
-
register(
McpResource resource) → void - Register a resource
-
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String uri) → void - Unregister a resource by URI
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited