MCPTransport class abstract
Transport interface for MCP communication
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool
-
Check if transport is running
no setter
-
requestStream
→ Stream<
McpRequest> -
Stream of incoming requests
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendNotification(
McpNotification notification) → Future< void> - Send a notification
-
sendResponse(
McpResponse response) → Future< void> - Send a response
-
start(
) → Future< void> - Start the transport
-
stop(
) → Future< void> - Stop the transport
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited