EndpointMethod class
Parsed method signature from endpoint
Constructors
-
EndpointMethod({required String name, required String returnType, required List<
MethodParameter> parameters, required String filePath, required int lineNumber})
Properties
- filePath → String
-
Source file path
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lineNumber → int
-
Line number in source file
final
- name → String
-
Method name
final
-
parameters
→ List<
MethodParameter> -
All parameters including Session session
final
- returnType → String
-
Return type (e.g., 'Greeting', 'List
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
Method signature as string
no setter
-
userParameters
→ List<
MethodParameter> -
Get parameters excluding Session session
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override