GitHubSkillFetcher class
Fetches skills from GitHub repositories
Constructors
- GitHubSkillFetcher({Client? client, String? cacheDir, String? skillsPath, String? githubApiUrl, String? githubRawUrl})
- Create a new GitHub skill fetcher
Properties
- cacheDir → String
-
Directory for caching fetched skills
final
- client → Client
-
HTTP client for making requests
final
- githubApiUrl → String
-
GitHub API base URL
final
- githubRawUrl → String
-
GitHub raw content base URL
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skillsPath → String
-
Local skills path for fallback
final
Methods
-
clearAllCache(
) → Future< void> - Clear all cached skills
-
clearCache(
String repo, String skillName, {String branch = 'main'}) → Future< void> - Clear the cache for a specific skill
-
close(
) → void - Close the HTTP client
-
fetchAllSkills(
String repo, {String branch = 'main'}) → Future< List< Skill> > - Fetch all available skills from a repository
-
fetchSkill(
String repo, String skillName, {String branch = 'main'}) → Future< Skill> - Fetch skill from GitHub repository
-
fetchSkills(
String repo, List< String> skillNames, {String branch = 'main'}) → Future<List< Skill> > - Fetch multiple skills from a repository
-
getCacheSize(
) → Future< int> - Get cache size in bytes
-
listSkills(
String repo, {String branch = 'main'}) → Future< List< String> > - List available skills from repository
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
skillExists(
String repo, String skillName, {String branch = 'main'}) → Future< bool> - Check if a skill exists in the repository
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited