SkillLoader class
Loads skills from the file system
Constructors
- SkillLoader({required String skillsPath})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skillsPath → String
-
Base path to skills directory
final
Methods
-
exists(
String name) → Future< bool> - Check if a skill exists
-
getSkillPath(
String name) → String - Get the skill directory path for a given skill name
-
listSkillNames(
) → Future< List< String> > - List all skill names
-
loadAll(
) → Future< List< Skill> > - Load all available skills
-
loadFromDirectory(
String subdirectory) → Future< List< Skill> > - Load skills from a specific subdirectory
-
loadSkill(
String name) → Future< Skill?> - Load a specific skill by name
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited