SkillMetadata class
Metadata about a skill
Constructors
-
SkillMetadata({String description = '', String version = '1.0.0', String? minServerpodVersion, List<
String> dependencies = const [], SkillSource source = const SkillSource.builtin(), List<String> tags = const []}) -
const
- SkillMetadata.fromYaml(Map yaml)
-
Create from YAML map
factory
Properties
-
dependencies
→ List<
String> -
Other skills this skill depends on
final
- description → String
-
Human-readable description
final
- hasDependencies → bool
-
Check if this skill has any dependencies
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasVersionRequirement → bool
-
Check if this skill has a minimum ServerPod version requirement
no setter
- minServerpodVersion → String?
-
Minimum ServerPod version required (optional)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SkillSource
-
Source of this skill
final
-
Tags for categorization
final
- version → String
-
Skill version
final
Methods
-
copyWith(
{String? description, String? version, String? minServerpodVersion, List< String> ? dependencies, List<String> ? tags, SkillSource? source}) → SkillMetadata - Create a copy of this metadata with some fields replaced
-
dependsOn(
String skillName) → bool - Check if this skill depends on another skill
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const SkillMetadata
- Default metadata instance