SkillSource class
Source information for a skill
Constructors
- SkillSource({required SkillSourceType type, String? location, String? version})
-
const
- SkillSource.builtin()
-
Create a built-in skill source
const
- SkillSource.cached()
-
Create a cached skill source
const
- SkillSource.github(String repo)
-
Create a GitHub skill source
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SkillSourceType
-
final
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited