SkillInfo class
Information about a single skill
Constructors
Properties
- category → String
-
Category (serverpod, remote, etc.)
final
- description → String
-
Description extracted from skill file
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Skill name (directory name)
final
- path → String
-
Path to the skill template file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON-serializable map
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited