CodeMatch class

Search result match

Constructors

CodeMatch({required String filePath, required String relativePath, required int lineNumber, required String line, required int start, required int end})

Properties

end int
Match end position
final
filePath String
File path
final
hashCode int
The hash code for this object.
no setterinherited
line String
Line content
final
lineNumber int
Line number (1-based)
final
relativePath String
Relative path from project root
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
Match start position
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited